@@ -84,7 +84,7 @@ StateBundle = namedtuple(
 
 class GraphicsContext(object):
     def __init__(self, size, *args, **kwargs):
-        super(GraphicsContext, self).__init__()
+        super().__init__()
         self._width = size[0]
         self._height = size[1]
         self.pix_format = kwargs.get('pix_format', 'bgra32')
